pub struct Material {
pub absorption: [f32; 3],
pub scattering: f32,
pub transmission: [f32; 3],
}Expand description
An acoustic material. The acoustic surface properties of an object are represented using multi-band absorption and transmission loss coefficients, and a single random-incidence scattering coefficient. All values are in the 0.0 to 1.0 range.
Fields
absorption: [f32; 3]scattering: f32transmission: [f32; 3]Trait Implementations
impl Copy for Material
impl StructuralPartialEq for Material