pub struct AudioBuffer<const N_CHANNELS: usize>(pub [Vec<f32>; N_CHANNELS]);Expand description
Phonon processes audio in audio buffers, which contain uncompressed Pulse Code Modulated (PCM) data (just like a .wav file).
Audio buffers contain one or more channels; for example, a stereo audio buffer contains 2 channels. Each channel typically contains several samples, which are values of the audio signal’s level at discrete points of time. Each channel has the same number of samples.
A sample is a 32-bit floating-point. The time interval between two successive samples is specified using the sampling rate. Typical sampling rates are 44100 Hz (CD quality) or 48000 Hz.
Interleaving
Phonon stores audio buffers in a deinterleaved layout. This means that all the samples for the first channel are store contiguously, followed by all the samples for the second channel, and so on.
Most audio formats instead use an interleaved layout, where data for each
frame is stored together in memory. Interleaved data can be read to and
written from using AudioBuffer::read_interleaved and AudioBuffer::write_interleaved.
Tuple Fields
0: [Vec<f32>; N_CHANNELS]Implementations
Sourceimpl<const N_CHANNELS: usize> AudioBuffer<N_CHANNELS>
impl<const N_CHANNELS: usize> AudioBuffer<N_CHANNELS>
Sourcepub fn new(num_samples: usize) -> Self
pub fn new(num_samples: usize) -> Self
Creates a new AudioBuffer with a fixed number of channels and samples.
Initalized to all zeros, representing silence.
Sourcepub fn num_channels(&self) -> usize
pub fn num_channels(&self) -> usize
Returns the number of channels this AudioBuffer has.
Sourcepub fn num_samples(&self) -> usize
pub fn num_samples(&self) -> usize
Returns the number of samples each channel has.
Sourcepub fn make_silent(&mut self)
pub fn make_silent(&mut self)
Fills the AudioBuffer with all zero samples, representing silence.
Sourcepub fn mix(&mut self, other: &AudioBuffer<N_CHANNELS>)
pub fn mix(&mut self, other: &AudioBuffer<N_CHANNELS>)
Mixes the AudioBuffer into another by adding samples together.
Sourcepub fn downmix(&self, output: &mut AudioBuffer<1>)
pub fn downmix(&self, output: &mut AudioBuffer<1>)
Mixes all channels on an AudioBuffer into a single output channel.
Downmixing is performed by summing up the source channels and dividing
the result by the number of source channels.
Sourcepub fn read_interleaved(&mut self, source: &[f32])
pub fn read_interleaved(&mut self, source: &[f32])
Reads a slice of interleaved samples into this AudioBuffer.
Sourcepub fn write_interleaved(&self, target: &mut [f32])
pub fn write_interleaved(&self, target: &mut [f32])
Writes the AudioBuffer to an interleaved slice.